# tofuref

[![PyPI - Version](https://img.shields.io/pypi/v/tofuref)](https://pypi.org/project/tofuref/)
![PyPI - License](https://img.shields.io/pypi/l/tofuref)
![PyPI - Downloads](https://img.shields.io/pypi/dm/tofuref)
![GitHub Repo stars](https://img.shields.io/github/stars/DJetelina/tofuref?style=flat&logo=github)
[![Matrix](https://img.shields.io/matrix/tofuref%3Ajtl.vision?server_fqdn=matrix.jtl.vision&fetchMode=guest&logo=matrix)](https://matrix.to/#/#tofuref:jtl.vision)

A terminal application to browse OpenTofu provider documentation.

![Screenshot](https://github.com/djetelina/tofuref/blob/main/screenshots/welcome.svg?raw=true)

## Installation

```bash
pipx install tofuref
```

## Usage

Run the application:

```bash
tofuref
```

## Upgrade

```bash
pipx upgrade tofuref
```
